Module quick_protobuf::message [−][src]
A module to deserialize a Message as defined in a .proto file
Creates the struct and implements a reader
Traits
| MessageRead |
A trait to handle deserialization from protocol buffers. |
| MessageWrite |
A trait to handle deserialization based on parsed |