Module quick_protobuf::reader [−][src]
A module to manage protobuf deserialization
There are actually two main readers
- a
BytesReaderwhich parses data from a&[u8] - a
Readerwhich is a wrapper onBytesReaderwhich has its own buffer. It provides convenient functions to the user suche asfrom_file
It is advised, for convenience to directly work with a Reader.
Structs
| BytesReader |
A struct to read protocol binary files |
| Reader |
A struct to read protobuf data |